![](https://user-images.githubusercontent.com/52009346/69100304-2eb3e800-0a5d-11ea-9a3a-8e502af2120b.png)

## Introduction
well_profile is a tool to generate or load well profiles in 3D. Features are added as they
are needed; suggestions and contributions of all kinds are very welcome.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Get well_profile

* Source code from [Github](https://github.com/pro-well-plan/well_profile)
    * `git clone https://github.com/pro-well-plan/well_profile`

    
## Contributing

Please read [CONTRIBUTING](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## History ##
This tool was initially written and is maintained by [Pro Well Plan
AS](http://www.prowellplan.com/) as a free, simple, easy-to-use way to perform
torque and drag calculations along the well that can be tailored to our needs, and as contribution to the
free software community.

## License

This project is licensed under the GNU Lesser General Public License v3.0 - see the [LICENSE](LICENSE.md) file for details


*for further information contact juan@prowellplan.com*
